==> core-react-0.8.0.tgz: package/es/Aside/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Button from '../Button';
import Dialog from '../dialog/Dialog';
import DialogBody from '../dialog/DialogBody';


var AsideCloseButton = /*#__PURE__*/function (_Component) {
  _inherits(AsideCloseButton, _Component);

  function AsideCloseButton() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, AsideCloseButton);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(AsideCloseButton)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "handleClose", function () {
      var _this$context, _this$context$dialog, _this$context$dialog$;

      (_this$context = _this.context) === null || _this$context === void 0 ? void 0 : (_this$context$dialog = _this$context.dialog) === null || _this$context$dialog === void 0 ? void 0 : (_this$context$dialog$ = _this$context$dialog.close) === null || _this$context$dialog$ === void 0 ? void 0 : _this$context$dialog$.call(_this$context$dialog);
    });

    return _this;
  }

  _createClass(AsideCloseButton, [{
    key: "render",
    value: function render() {
      return React.createElement(Button, {
        className: "".concat("waui", "-aside__header-close"),
        icon: "close",
        onClick: this.handleClose
      });
    }
  }]);

  return AsideCloseButton;
}(Component);

_defineProperty(AsideCloseButton, "contextTypes", {
  dialog: PropTypes.object
});

var Aside = /*#__PURE__*/function (_React$Component) {
  _inherits(Aside, _React$Component);

  function Aside() {
    var _this2;

    _classCallCheck(this, Aside);

    _this2 = _possibleConstructorReturn(this, _getPrototypeOf(Aside).call(this));
    _this2.state = {
      hasTabsChildren: false
    };
    return _this2;
  }

  _createClass(Aside, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      var _this3 = this;

      React.Children.forEach(this.props.children, function (child) {
        var _child$type;

        // TODO child.props.mdxType
        (child === null || child === void 0 ? void 0 : (_child$type = child.type) === null || _child$type === void 0 ? void 0 : _child$type.name) === 'Tabs' && _this3.setState({
          hasTabsChildren: true
        });
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          children = _this$props.children,
          isOpen = _this$props.isOpen,
          title = _this$props.title,
          onClose = _this$props.onClose,
          other = _objectWithoutProperties(_this$props, ["className", "children", "isOpen", "title", "onClose"]);

      return React.createElement("div", {
        className: cx("".concat("waui", "-aside"), className)
      }, !!isOpen && React.createElement(Dialog, _extends({
        onClose: onClose,
        type: "aside",
        backdrop: true
      }, other), React.createElement("div", {
        className: cx("".concat("waui", "-aside__header"), _defineProperty({}, "".concat("waui", "-aside__header_with-tabs"), this.state.hasTabsChildren))
      }, React.createElement("div", {
        className: "".concat("waui", "-aside__header-title")
      }, title), React.createElement(AsideCloseButton, null)), React.createElement(DialogBody, null, children)));
    }
  }]);

  return Aside;
}(React.Component);

Aside.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** Whether to open Aside  */
  isOpen: PropTypes.bool.isRequired,

  /** The callback of closing Aside  */
  onClose: PropTypes.func.isRequired,
  onOpen: PropTypes.func,

  /** The title of Aside  */
  title: PropTypes.string
};
export default Aside;

==> core-react-0.8.2.tgz: package/es/Aside/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Button from '../Button';
import Dialog from '../dialog/Dialog';
import DialogBody from '../dialog/DialogBody';


var AsideCloseButton = /*#__PURE__*/function (_Component) {
  _inherits(AsideCloseButton, _Component);

  function AsideCloseButton() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, AsideCloseButton);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(AsideCloseButton)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "handleClose", function () {
      var _this$context, _this$context$dialog, _this$context$dialog$;

      (_this$context = _this.context) === null || _this$context === void 0 ? void 0 : (_this$context$dialog = _this$context.dialog) === null || _this$context$dialog === void 0 ? void 0 : (_this$context$dialog$ = _this$context$dialog.close) === null || _this$context$dialog$ === void 0 ? void 0 : _this$context$dialog$.call(_this$context$dialog);
    });

    return _this;
  }

  _createClass(AsideCloseButton, [{
    key: "render",
    value: function render() {
      return (/*#__PURE__*/React.createElement(Button, {
          className: "".concat("waui", "-aside__header-close"),
          icon: "close",
          onClick: this.handleClose
        })
      );
    }
  }]);

  return AsideCloseButton;
}(Component);

_defineProperty(AsideCloseButton, "contextTypes", {
  dialog: PropTypes.object
});

var Aside = /*#__PURE__*/function (_React$Component) {
  _inherits(Aside, _React$Component);

  function Aside() {
    var _this2;

    _classCallCheck(this, Aside);

    _this2 = _possibleConstructorReturn(this, _getPrototypeOf(Aside).call(this));
    _this2.state = {
      hasTabsChildren: false
    };
    return _this2;
  }

  _createClass(Aside, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      var _this3 = this;

      React.Children.forEach(this.props.children, function (child) {
        var _child$type;

        // TODO child.props.mdxType
        (child === null || child === void 0 ? void 0 : (_child$type = child.type) === null || _child$type === void 0 ? void 0 : _child$type.name) === 'Tabs' && _this3.setState({
          hasTabsChildren: true
        });
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          children = _this$props.children,
          isOpen = _this$props.isOpen,
          title = _this$props.title,
          onClose = _this$props.onClose,
          other = _objectWithoutProperties(_this$props, ["className", "children", "isOpen", "title", "onClose"]);

      return (/*#__PURE__*/React.createElement("div", {
          className: cx("".concat("waui", "-aside"), className)
        }, !!isOpen && /*#__PURE__*/React.createElement(Dialog, _extends({
          onClose: onClose,
          type: "aside",
          backdrop: true
        }, other), /*#__PURE__*/React.createElement("div", {
          className: cx("".concat("waui", "-aside__header"), _defineProperty({}, "".concat("waui", "-aside__header_with-tabs"), this.state.hasTabsChildren))
        }, /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-aside__header-title")
        }, title), /*#__PURE__*/React.createElement(AsideCloseButton, null)), /*#__PURE__*/React.createElement(DialogBody, null, children)))
      );
    }
  }]);

  return Aside;
}(React.Component);

Aside.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** Whether to open Aside  */
  isOpen: PropTypes.bool.isRequired,

  /** The callback of closing Aside  */
  onClose: PropTypes.func.isRequired,
  onOpen: PropTypes.func,

  /** The title of Aside  */
  title: PropTypes.string
};
export default Aside;
